<?php

namespace Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\GER\Utilities\Environment;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification; 
use Teknisa\Libs\Util\NewCode;
use Services\ParametrosDashboardService;

class ParametrosDashboardController{
    // /** @var \Services\Settings */
    // private $settingService;
    // /** @var \Services\Password $passwordService */
    // protected $passwordService;
    protected $entityManager;
    protected $connection;
    protected $newCode;

    public function __construct($entityManager, $connection, $environment, $newCode, ParametrosDashboardService $service) {
        $this->entityManager = $entityManager;
        $this->connection = $connection;
        $this->environment = $environment;
        $this->newCode = $newCode;
        $this->service = $service;
    }

    public function updateIdpadraodash(Request\DataSet $request, Response $response) {
        $currentRow = $request->getDataSet()->getRows()[0];

        $params = array(
            "P_CDFILIAL" => $currentRow["CDFILIAL"],
            "P_NRPERFILACESSO" => $currentRow["NRPERFILACESSO"]
        );
        
        $this->service->updateIdpadraodash($params);
    }
   
    public function savePerfil(Request\DataSet $request, Response $response) {
        $currentRow = $request->getDataSet()->getRows()[0];
        
        try{
            if($currentRow["__is_new"]){
                $nrperfaclpainel = intval($this->newCode->getCodeByTableName("PERFACLPAINEL", $this->environment->getNrOrgTrab()));
                $params = array(
                    "P_NRPERFACLPAINEL" => $nrperfaclpainel,
                    "P_NRPAINEL" => $currentRow["NRPAINEL"],
                    "P_NRPERFILACESSO" => $currentRow["NRPERFILACESSO"],
                    "P_CDFILIAL" => $currentRow["CDFILIAL"],
                    "P_IDPADRAODASH" => $currentRow["IDPADRAODASH"],
                    "P_NRORG" => $this->environment->getNrorg()
                );
                $this->service->insertPerfaclpainel($params);
                $response->addDataSet(new DataSet("nrperfaclpainel", [$nrperfaclpainel]));
            }else{
                $params = array(
                    "P_NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"],
                    "P_IDPADRAODASH" => $currentRow["IDPADRAODASH"],
                    "P_NRORG" => $this->environment->getNrorg()
                );
                 $this->service->updatePerfaclpainel($params);
            }
		}catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getIdPadraoDash(Request\DataSet $request, Response $response) {
        $currentRow = $request->getDataSet()->getRows()[0];

        $params = array(
            "P_CDFILIAL" => $currentRow["CDFILIAL"],
            "P_NRPAINEL" => $currentRow["NRPAINEL"],
            "P_NRPERFILACESSO" => $currentRow["NRPERFILACESSO"]
        );
        $return = $this->service->getIdPadraoDash($params);
		
		try{
    		$response->addDataSet(new DataSet("idpadraodash", $return));
		}catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function saveIndicadorInLine(Request\DataSet $request, Response $response){
        $rows = $request->getDataSet()->getRows();
        try{
            foreach($rows as $row){
                if($row["__is_new"]){
                    $nrindicpainel = intval($this->newCode->getCodeByTableName("INDICPAINEL", $this->environment->getNrOrgTrab()));
                    $params = array(
                        "P_NRINDICPAINEL" => $nrindicpainel,
                        "P_NRPERFACLPAINEL" =>  $row["NRPERFACLPAINEL"],
                        "P_NRINDICADORTF" => $row["NRINDICADORTF"],
                        "P_IDVISUINDIC" => $row["IDVISUINDIC"],
                        "P_NRORG" => $this->environment->getNrorg()
                    );
                    $this->service->insertIndicpainel($params);
                    $response->addDataSet(new DataSet("nrindicpainel", [$nrindicpainel]));
                }else{
                    $params = array(
                        "P_NRINDICPAINEL" => $row["NRINDICPAINEL"],
                        "P_IDVISUINDIC" => $row["IDVISUINDIC"],
                        "P_NRORG" => $this->environment->getNrorg()
                    );
                     $this->service->updateIndicpainel($params);
                    $response->addDataSet(new DataSet("nrindicpainel", [$row["NRINDICPAINEL"]]));
                }
            }
		}catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function saveIndicador(Request\DataSet $request, Response $response) {
        $currentRow = $request->getDataSet()->getRows()[0];
        
        try{
            if($currentRow["__is_new"]){
                $nrindicpainel = intval($this->newCode->getCodeByTableName("INDICPAINEL", $this->environment->getNrOrgTrab()));
                $params = array(
                    "P_NRINDICPAINEL" => $nrindicpainel,
                    "P_NRPERFACLPAINEL" =>  $currentRow["NRPERFACLPAINEL"],
                    "P_NRINDICADORTF" => $currentRow["NRINDICADORTF"],
                    "P_IDVISUINDIC" => $currentRow["IDVISUINDIC"],
                    "P_NRORG" => $this->environment->getNrorg()
                );
                $this->service->insertIndicpainel($params);
                $response->addDataSet(new DataSet("nrindicpainel", [$nrindicpainel]));
            }else{
                $params = array(
                    "P_NRINDICPAINEL" => $currentRow["NRINDICPAINEL"],
                    "P_IDVISUINDIC" => $currentRow["IDVISUINDIC"],
                    "P_NRORG" => $this->environment->getNrorg()
                );
                 $this->service->updateIndicpainel($params);
                $response->addDataSet(new DataSet("nrindicpainel", [$currentRow["NRINDICPAINEL"]]));
            }
		}catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function saveExOperadorIndicador(Request\Row $request, Response $response) {
        $currentRow = $request->getRow();
        $nrorg = $this->environment->getNrOrgTrab();
        try{
            
            foreach($currentRow['OPERADOR'] as $cdoperador){
                
                $nrindicpainexcoper = intval($this->newCode->getCodeByTableName('INDICPAINEXCOPER', $this->environment->getNrOrgTrab()));
                
                $params = array(
                    "P_NRINDICPAINEXCOPER" => $nrindicpainexcoper,
                    "P_NRINDICPAINEL" => $currentRow["NRINDICPAINEL"],
                    "P_CDOPERADOR" => $cdoperador,
                    "P_NRORG" => $this->environment->getNrOrgTrab()
                );
                $this->service->insertExOperadorIndicador($params);
            }
    		$response->addDataSet(new DataSet("nrindicpainexcoper", [$nrindicpainexcoper]));
		}catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
        
    }
    
    public function saveExOperadorPainel(Request\DataSet $request, Response $response) {
        $currentRow = $request->getDataSet()->getRows()[0];
        $nrorg = $this->environment->getNrorg();
        $filterCountIndicadortf = array(
            "P_NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"]
        );
        
        
        $countIndicadortf = $this->service->countIndicadortf($filterCountIndicadortf);
        if(!empty($countIndicadortf)){
            $nrindicpainel = intval($this->newCode->getCodeByTableName('INDICPAINEL', $this->environment->getNrOrgTrab(), $countIndicadortf));
            if($nrindicpainel != 1){
                $nrindicpainel = $nrindicpainel - 1;    
            }
            $filterInsertAllIndicador = array(
                "P_NRINDICPAINEL" => $nrindicpainel,
                "P_NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"],
                "P_NRORG" => $nrorg,
                "P_NRPAINEL" => $currentRow["NRPAINEL"]
            );
            
            $this->service->insertAllIndicpainel($filterInsertAllIndicador);
        }
        $filterCountIndicpainel = array(
            "P_NRPAINEL" => $currentRow["NRPAINEL"]
        );
        
        $countIndicador = $this->service->countIndicador($filterCountIndicpainel);
        
        foreach($currentRow["OPERADOR"] as $cdoperador){
            $nrindicpainexoper = intval($this->newCode->getCodeByTableName('INDICPAINEXCOPER', $nrorg, $countIndicador));
            if($nrindicpainexoper != 1){
                $nrindicpainexoper = $nrindicpainexoper - 1;
            }
            $filterInsertOperador = array(
                "P_NRINDICPAINEXOPER" => $nrindicpainexoper,
                "P_NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"],
                "P_CDFILIAL" => $currentRow["CDFILIAL"],
                "P_CDOPERADOR" => $cdoperador,
                "P_NRORG" => $nrorg
            );
            
    		$this->service->insertExOperadorPainel($filterInsertOperador);
        }
        
    }
    
    public function deleteExOperadorPainel(Request\DataSet $request, Response $response) {
        $rows = $request->getDataSet()->getRows()[0];
        $currentRow = $rows[0];
        // $rows = array_shift($dados);
        unset($rows[0]);
        //falta excluir um por um (colocar chamada dentro do for each ou passar um parametro com todos os dados)
        $cdoperador = array();
        
        foreach ($rows as $row){
            if(preg_match('/^([a-z0-9A-Z]){12}$/', $row['CDOPERADOR'])){
                array_push($cdoperador, "'".$row['CDOPERADOR']."'");
            }
        }
        $params = array(
            "P_NRPAINEL" => $currentRow["NRPAINEL"],
            "P_NRPERFILACESSO" => $currentRow["NRPERFILACESSO"],
            "P_CDFILIAL" => $currentRow["CDFILIAL"]
        );
		$this->service->deleteExOperadorPainel($params, $cdoperador);
    }
   
    public function updatePadrao (Request\DataSet $request, Response $response){
        $row = $request->getDataSet()->getRows()[0];
        $params = array(
            "P_IDUTLDSBTPADRAO" => $row["IDUTLDSBTPADRAO"],
            "P_CDFILIAL" => $row["CDFILIAL"],
            "P_NRORG" => $this->environment->getNrorg()
        );
        $this->service->updatePadrao($params);
        
    }
    
    public function replicar (Request\DataSet $request, Response $response){
        $data = $request->getDataSet()->getRows()[0];
        $nrorg = $this->environment->getNrorg();
        $nrlista = false;
        
        try{
            
            if($data['P_PADRAO'] == 'S'){
                $data['CDFILIAL_ORIGEM'] = 'P';
            }
            
            if($data['TODAS_UNIDADES'] == 'S'){
                $nrlista = 'T';
                $paramsDelete = array(
                    "P_CDFILIAL" => $data['CDFILIAL_ORIGEM'],
                    "P_NRPAINEL" => null,
                    "P_NRORG" => $nrorg
                );
                $this->service->deleteTodasUnidades($paramsDelete);
            }else{
                $data['FILIAL_DESTINO'][0] = $data['FILIAL_DESTINO'][0] === "" ? 'P' : $data['FILIAL_DESTINO'][0];
                $nrlista = $this->criarListaValores(implode('_',$data['FILIAL_DESTINO']));
                $nrlista = str_replace('_NRLISTA=', '', $nrlista);
                $paramsDelete = array(
                    "P_NRLISTA" => $nrlista,
                    "P_NRPAINEL" => null,
                    "P_NRORG" => $nrorg
                );
                $this->service->deleteParametrizacaoUnidades($paramsDelete);
            }
            
            
            if($nrlista){

                // Chamada de script
                $paramsReplicar = array(
                    "P_NRLISTA" => $nrlista,
                    "P_CDFILIAL" => $data['CDFILIAL_ORIGEM'],
                    "P_NRORG" => $nrorg
                );
                $this->service->insereReplicar($paramsReplicar);
                
                if ($nrlista != 'T') {
                    $this->service->deleteLista($nrlista);
                }
            }

        }catch(CustomException $e) {
            if($nrlista)
                $this->service->deleteLista(str_replace('_NRLISTA=', '', $nrlista));
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function cadastrar (Request\DataSet $request, Response $response){
        $data = $request->getDataSet()->getRows()[0];
        $nrorg = $this->environment->getNrorg();
        $nrlista = false;
        
        try{
            
            if($data['UTILIZA_PADRAO'] == 'S'){
                $nrlistaPerfil = null;
                $data['NRPAINEL'] = null;
                
                $indicador = null;
                $nrlistaPerfil = null;
                $nrlistaUnidade = null;
                $nrlistaExcecao = null;
                
                
                // cria lista de unidades mas não exclui parametrização
                if($data['TODAS_UNIDADES'] == 'S'){
                    $nrlistaUnidade = $this->criarListaValores('T');
                }else{
                    $nrlistaUnidade = $this->criarListaValores(implode('_', $data['FILIAL_DESTINO']));
                }
                
                $nrlistaUnidade = str_replace('_NRLISTA=', '', $nrlistaUnidade);
                
                
            }else{
                $nrlistaPerfil = $this->criarListaValores(implode('_', $data['PERFIL']));
                $nrlistaPerfil = str_replace('_NRLISTA=', '', $nrlistaPerfil);
                
                if($data['TODAS_UNIDADES'] == 'S'){
                    $nrlistaUnidade = $this->criarListaValores('T');
                    $nrlistaUnidade = str_replace('_NRLISTA=', '', $nrlistaUnidade);
                    $paramsDelete = array(
                        "P_CDFILIAL" => 'T',
                        "P_NRPAINEL" => $data['NRPAINEL'],
                        "P_NRORG" => $nrorg
                    );
                    $this->service->deleteTeste($paramsDelete);
                    $this->service->deleteTodasUnidades($paramsDelete);
                }else{
                    $nrlistaUnidade = $this->criarListaValores(implode('_', $data['FILIAL_DESTINO']));
                    $nrlistaUnidade = str_replace('_NRLISTA=', '', $nrlistaUnidade);
                    $paramsDelete = array(
                        "P_NRLISTA" => $nrlistaUnidade,
                        "P_NRPAINEL" => $data['NRPAINEL'],
                        "P_NRORG" => $nrorg
                    );
                    $this->service->deleteParametrizacaoUnidades($paramsDelete);
                }
                
                if(\Zeedhi\Framework\Util\Functions::arrayKeyExists('EXCECAO', $data)){
                    if($data['EXCECAO'] == ""){
                        $nrlistaExcecao = null;
                    }else{
                        $nrlistaExcecao = $this->criarListaValores(implode('_', $data['EXCECAO']));
                        $nrlistaExcecao = str_replace('_NRLISTA=', '', $nrlistaExcecao);
                    }
                }else{
                    $nrlistaExcecao = null;
                }
                
                if(\Zeedhi\Framework\Util\Functions::arrayKeyExists('INDICADOR', $data)){
                    if($data['INDICADOR'] == ""){
                        $indicador = null;
                    }else{
                        $indicador = '_'.implode('_', $data['INDICADOR']).'_';
                    }
                }else{
                    $indicador = null;
                }
            }
            
            
            $paramsCadastrar = array(
                "P_NRLISTA_UNIDADE" => $nrlistaUnidade,
                "P_UTILIZA_PADRAO" => $data['UTILIZA_PADRAO'],
                "P_PAINEL" => $data['NRPAINEL'],
                "P_NRLISTA_PERFIL" => $nrlistaPerfil,
                "P_INDICADOR_VISIVEL" => $indicador,
                "P_NRLISTA_EXCECAO" => $nrlistaExcecao,
                "P_NRORG" => $nrorg
            );
        
            $this->service->insereCadastrar($paramsCadastrar);
            
            
            $this->service->deleteLista($nrlistaUnidade);
            $this->service->deleteLista($nrlistaPerfil);
            $this->service->deleteLista($nrlistaPerfil);
            
        }catch(CustomException $e) {
            $this->service->deleteLista(str_replace('_NRLISTA=', '', $nrlistaUnidade));
            $this->service->deleteLista(str_replace('_NRLISTA=', '', $nrlistaPerfil));
            $this->service->deleteLista(str_replace('_NRLISTA=', '', $nrlistaPerfil));
            $response->setError(Utilities::getErrorObjectFromException($e));
        }

    }

    //cria lista de valores recebendo string como parametro
    public function criarListaValores($valores){
        $this->entityManager->beginTransaction();
        $lista = explode('_',$valores);
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
        try{
            foreach($lista as $key){
                $this->service->insertLista($nrlista, $key);
            }
            $this->entityManager->commit();
            return "_NRLISTA=".$nrlista;
        } catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    
    public function checkIndicator (Request\DataSet $request, Response $response){
        $arrayInsert=[
            1=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (1, 'Dias de Estoque', 1)",
            2=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (2, 'Data de Processamento', 1)",
            3=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (3, 'Dias de Atraso', 1)",
            4=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (4, 'Valor de Ajuste', 1)",
            5=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES (5, 'Valor de Solicitações Extras', 1)",
            6=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (6, 'Análise de Custo', 1)",
            7=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (7, 'Análise de PU do dia', 1)",
            8=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (8, 'Inflação', 1)",
            9=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (9, 'Entregas de Hoje', 1)",
            10=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (10, 'Resumo DRO', 1)",
            11=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (11, 'Produtos sem Movimentação há mais de 30 dias', 1)",
            12=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (12, 'Análise de Custo', 11)",
            13=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (13, 'Percentual de Ajuste  Consumo', 11)",
            14=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (14, 'Resumo DRO', 11)",
            15=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (15, 'Dias de Estoque', 11)",
            16=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (16, 'Acompanhamento de Efetivos', 22)",
            17=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (17, 'Comparativo de Custo', 22)",
            18=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (18, 'Análise de Custo - Acumulado até', 1)",
            19=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES ('19', 'Desvio de Consumo', '1')",
            20=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES ('20', 'Próxima Liberação de Cardápio', '1')",
            21=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES ('21', 'Dias para Aprovação de Cardápio', '1')",
            22=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES ('22', 'Impacto Financeiro', '1')",
            23=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES ('23', 'Lançamentos Pendentes (XML x NF)', '1')",
            24=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES ('24', 'Orçamento do Consumo', '1')",
            25=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)  VALUES ('25', 'Orçamento do Período', '1')",
            26=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL, IDATIVO) VALUES (26, 'Resumo DRO - Grade', 1)",
            27=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL, IDATIVO) VALUES (27, 'Consumo Workflow', 1)",
            28=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (28, 'Acompanhamento de Aprovação de AF', 33)",
            29=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (29, 'Entrega Total de AF', 33)",
            30=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (30, 'Entrega de AF - Últimos 7 dias', 33)",
            31=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (31, 'Entrega de AF - Mês atual', 33)",
            32=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (32, 'Entrega de AF - Anual', 33)",
            33=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (33, 'Entrega de AF - Mes Atual (Comprador)', 33)",
            34=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (34, 'AFs Confirmadas pelo Fornecedor', 33)",
            35=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (35, 'Media de Atraso do Lancamento de NF', 33)",
            36=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (36, 'Orçamento de Despesa', 1)",
            37=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL)VALUES (37, 'Despesa Workflow', 1)"
        ];  
        $length = count($arrayInsert);
        $params = [
            ':P_LENGTH' =>  $length
        ];
        $query = "SELECT ROWNUM SEQUENCIAL FROM DUAL CONNECT BY LEVEL <= :P_LENGTH
                   MINUS
                  SELECT NRINDICADORTF SEQUENCIAL FROM INDICADORTF";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
		    $result = $stmt->fetchAll();
		    if(count($result) > 0){
		       $this->insertIdicator($arrayInsert, $result);
		    }
        } catch (Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
        
    }
    
    public function insertIdicator ($arrayInsert, $result){
        $this->entityManager->beginTransaction();
        try {
            foreach($result as $row){
                $stmt = $this->connection->prepare($arrayInsert[$row['SEQUENCIAL']]);
                $stmt->execute();
            }      
            $this->entityManager->commit();
        } catch (Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        } 
    }

} 