-- ============================================================
--   TABLE: USR_SAP_ME_ENDERECO 
-- ============================================================
CREATE TABLE USR_SAP_ME_ENDERECO
(
     ALTERACAO            VARCHAR2(01)       DEFAULT 'T' NOT NULL,
     IDENTIFIC            VARCHAR2(10)                   NOT NULL,
     CDFILIAL             VARCHAR2(04)                   NOT NULL,
     IDTIPOENDERECO       VARCHAR2(01)                   NOT NULL,
	     CONSTRAINT CKC_IDTIPOENDERECO_USR_END CHECK (IDTIPOENDERECO IN ('E','F','C')),
	     -- E = Endereo da filial, F = endereo de faturamento (da empresa principal ou relacionada) e C = endereo de cobrana
     CDPAIS               VARCHAR2(04)                   NOT NULL,
     PAIS                 VARCHAR2(30)                   NOT NULL,
     ESTADO               VARCHAR2(02)                   NOT NULL,
     CDMUNICIPIO          VARCHAR2(04)                   NOT NULL,
     MUNICIPIO            VARCHAR2(30)                   NOT NULL,
     DSENDERECO           VARCHAR2(50)                   NOT NULL,
     COMPLEMENTO          VARCHAR2(200)                      NULL,
     CONTATO              VARCHAR2(40)                       NULL,
     TEL                  VARCHAR2(25)                       NULL,
     EMAIL                VARCHAR2(200)                      NULL,
     CDBAIRRO             VARCHAR2(10)                       NULL,
     BAIRRO               VARCHAR2(50)                       NULL,
     CEP                  VARCHAR2(15)                       NULL,
     CANCELADO            VARCHAR2(01)       DEFAULT 'N' NOT NULL
         CONSTRAINT CKC_CANCELADO_USR_END CHECK (CANCELADO IN ('S','N')),
         -- N = Pedido no cancelado e S = Pedido cancelado
     IDINTERFACE          NUMBER                         NOT NULL,
     TPINTERFACE          VARCHAR2(01)                   NOT NULL
	     CONSTRAINT CKC_TPINTERFACE_USR_END CHECK (TPINTERFACE IN ('I','A','E')),
	     --Tipo de transao realizada - I = Incluso, A = Alterao e E = Excluso
     DTINTERFACEORI       DATE                           NOT NULL,
     DTINTERFACEDEST      DATE                           NULL,
     STATUS               NUMBER                         NOT NULL
  	     CONSTRAINT CKC_STATUS_USR_SAP_END CHECK (STATUS IN (0,1,2,3)),
	     -- 0 = ok, 1 = novo, 2 = erro e 3 = em processamento
     APPORIGEM            NUMBER                         NOT NULL
  	     CONSTRAINT CKC_APPORIGEM_USR_SAP_END CHECK (APPORIGEM IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
     APPDESTINO           NUMBER                         NOT NULL
	     CONSTRAINT CKC_APPDESTINO_USR_SAP_END CHECK (APPDESTINO IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
	 NRORG                NUMBER             DEFAULT 1   NOT NULL,
     IDATIVO              VARCHAR2(1)        DEFAULT 'S' NOT NULL
         CONSTRAINT CKC_IDATIVO_USR_END CHECK (IDATIVO IN ('S','N')),
     DTINCLUSAO           DATE                               NULL,
     DTULTATU             DATE                               NULL,
     NRORGINCLUSAO        NUMBER             DEFAULT 1       NULL,
     CDOPERINCLUSAO       VARCHAR2(12)       DEFAULT '1'     NULL,
     NRORGULTATU          NUMBER             DEFAULT 1       NULL,
     CDOPERULTATU         VARCHAR2(12)       DEFAULT '1'     NULL,
     IDTABALTTEK          VARCHAR2(1)        NULL
         CONSTRAINT CKC_IDTABALTTEK_USR_END CHECK ((IDTABALTTEK IS NULL) OR (IDTABALTTEK IN ('F', 'C', '1', '2', 'X', 'E'))),
     NRINSJURFILI         VARCHAR2(20)       NULL,
     CDINSCESTA           VARCHAR2(16)       NULL
)
/

CREATE INDEX SUP00325_FK ON USR_SAP_ME_ENDERECO(IDENTIFIC, CDFILIAL, IDTIPOENDERECO)
/

CREATE INDEX SUP00326_FK ON USR_SAP_ME_ENDERECO(CDPAIS, ESTADO, CDMUNICIPIO, CDBAIRRO)
/
                                                               
-- ============================================================
--   TABLE: USR_SAP_AUTOFORNE
-- ============================================================
CREATE TABLE USR_SAP_AUTOFORNE
(
     ALTERACAO                    VARCHAR2(01)        DEFAULT 'T' NOT NULL,
     IDENTIFIC                    VARCHAR2(10)                    NOT NULL,
     RESUMO                       VARCHAR2(500)                       NULL,
     OBSCLI                       VARCHAR2(500)                       NULL,
     DSPERIENTFIL                 VARCHAR2(50)                        NULL,
     DATAENTREGA                  DATE                                NULL,
     EXTRA                        VARCHAR2(4000)                      NULL,
     LOCALENTREGA                 VARCHAR2(200)                       NULL,
     LOCALFATURAMENTOCLIENTE      VARCHAR2(200)                       NULL,
     LOCALCOBRANCACLIENTE         VARCHAR2(200)                       NULL,
     CENTRO                       VARCHAR2(04)                    NOT NULL,
     TEL                          VARCHAR2(25)                        NULL,
     FORNECEDORCLIENTE            VARCHAR2(20)                    NOT NULL,
     DTAUTOFORN                   DATE                            NOT NULL,
     TAG                          VARCHAR2(12)                    NOT NULL,
     LOGIN                        VARCHAR2(12)                    NOT NULL,
     CDFORMPGTO                   VARCHAR2(02)                        NULL,
     IDTPFORPGTAF                 VARCHAR2(1)                         NULL
         CONSTRAINT CKC_IDTPFORPGTAF_USR_AF CHECK (IDTPFORPGTAF IS NULL OR (IDTPFORPGTAF IN ('F','V'))),
	     -- F = Data de pagamento fixa, V = Define data de pagamento e nulo quando no h forma de pagamento definida
     IDTIPOEMITAF                 VARCHAR2(1)                     NOT NULL
         CONSTRAINT CKC_IDTIPOEMITAF_USR_AF CHECK (IDTIPOEMITAF IN ('1','2','3')),
	     -- Emitente da AF. 1 = Empresa da filial, 2 = Empresa informada e 3 = cliente principal
     EMPRESA                      VARCHAR2(02)                    NOT NULL,
     NRPARCPGTOAF                 NUMBER                              NULL,
     NRDIAPGFIXAF                 NUMBER                              NULL,
     IDUTDIAPGTAF                 VARCHAR2(01)                        NULL
         CONSTRAINT CKC_IDUTDIAPGTAF_USR_AF CHECK (IDUTDIAPGTAF IS NULL OR (IDUTDIAPGTAF IN ('I','E'))),
	     --Preenchido quando utiliza data fixa na forma de pagamento e verifica se considera o ms atual (I) ou no (E)
     VRTOTALAF                    FLOAT                           NOT NULL,
     IDBAIXAAF                    VARCHAR2(1)                         NULL
         CONSTRAINT CKC_IDBAIXAAF_USR_AF CHECK (IDBAIXAAF IS NULL OR (IDBAIXAAF IN ('1','2','3','4','5','6','7'))),
		 --Identificador da baixa da AF. NULL = Em aberto, 1 = Parcial, 2 = Total, 3 = Manual, 4= encerrada, 5 = cancelada, 6 = em anlise e 7 = EDI
     IDBAIXAFSAI                  VARCHAR2(1)                         NULL
         CONSTRAINT CKC_IDBAIXAFSAI_USR_AF CHECK (IDBAIXAFSAI IS NULL OR (IDBAIXAFSAI IN ('1','2','3','4','5','6'))),
		 --Identificador do tipo de baixa de sada da AF do OL. NULL = Em aberto, 1 = Parcial, 2 = Total, 3 = Manual, 4= encerrada, 5 = cancelada e 6 = bloqueada
     IDAFEXPIRADA                VARCHAR2(1)          DEFAULT 'N'     NULL
         CONSTRAINT CKC_IDAFEXPIRADA_USR_AF CHECK (IDAFEXPIRADA IS NULL OR (IDAFEXPIRADA IN ('S','N'))),
     CANCELADO                   VARCHAR2(01)         DEFAULT 'N' NOT NULL,
         CONSTRAINT CKC_CANCELADO_USR_AF CHECK (CANCELADO IN ('S','N')),
         -- N = Pedido no cancelado e S = Pedido cancelado
     IDINTERFACE                 NUMBER                            NOT NULL,
     TPINTERFACE                 VARCHAR2(01)                      NOT NULL
	     CONSTRAINT CKC_TPINTERFACE_USR_AF CHECK (TPINTERFACE IN ('I','A','E')),
	     --Tipo de transao realizada - I = Incluso, A = Alterao e E = Excluso
     DTINTERFACEORI              DATE                              NOT NULL,
     DTINTERFACEDEST             DATE                                  NULL,
     STATUS                      NUMBER                            NOT NULL
  	     CONSTRAINT CKC_STATUS_USR_SAP_AF CHECK (STATUS IN (0,1,2,3)),
	     -- 0 = ok, 1 = novo, 2 = erro e 3 = em processamento
     APPORIGEM                   NUMBER                            NOT NULL
  	     CONSTRAINT CKC_APPORIGEM_USR_SAP_AF CHECK (APPORIGEM IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
     APPDESTINO                  NUMBER                            NOT NULL
	     CONSTRAINT CKC_APPDESTINO_USR_SAP_AF CHECK (APPDESTINO IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
     NRORG                       NUMBER                DEFAULT 1   NOT NULL,
     IDATIVO                     VARCHAR2(1)           DEFAULT 'S' NOT NULL
         CONSTRAINT CKC_IDATIVO_USR_AUTOFORN CHECK (IDATIVO IN ('S','N')),
     DTINCLUSAO                  DATE                                  NULL,
     DTULTATU                    DATE                                  NULL,
     NRORGINCLUSAO               NUMBER                DEFAULT 1       NULL,
     CDOPERINCLUSAO              VARCHAR2(12)          DEFAULT '1'     NULL,
     NRORGULTATU                 NUMBER                DEFAULT 1       NULL,
     CDOPERULTATU                VARCHAR2(12)          DEFAULT '1'     NULL
)
/

CREATE INDEX SUP00327_FK ON USR_SAP_AUTOFORNE(IDENTIFIC)
/

-- ============================================================
--   TABLE: USR_SAP_ITEMAUTF 
-- ============================================================
CREATE TABLE USR_SAP_ITEMAUTF
(
     ALTERACAO                   VARCHAR2(01)        DEFAULT 'T' NOT NULL,
     NUMEROITEM                  NUMBER(04)                    NOT NULL,
     CDPRODUTO                   VARCHAR2(20)                    NOT NULL,
     IDENTIFIC                   VARCHAR2(10)                    NOT NULL,
     CENTRO                      VARCHAR2(04)                    NOT NULL,
     DESCRICAO                   VARCHAR2(125)                   NOT NULL,
     COMPLEMENTO                 VARCHAR2(4000)                      NULL,
     UNIDADE                     VARCHAR2(20)                        NULL,
     CODIGO_GRUPO                VARCHAR2(20)                        NULL,
     GRUPO_PRODUTO               VARCHAR2(50)                        NULL,
     FABRICANTE                  VARCHAR2(100)                       NULL,
     DTPROGENTAF                 DATE                            NOT NULL,
     QUANTIDADE                  FLOAT                           NOT NULL,
     QTEFETENTRAF                FLOAT                               NULL,
     PRECO                       FLOAT                           NOT NULL,
     IDBAIXITMAF                 VARCHAR2(1)                          NULL
         CONSTRAINT CKC_IDBAIXITMAF_USR_SAP_ITMAF CHECK (IDBAIXITMAF IS NULL OR (IDBAIXITMAF IN ('1','2','3'))),
         -- null = em aberto, 1 = parcial, 2 = total e 3  = manual
     IDBAIXITAFS                 VARCHAR2(1)                          NULL
         CONSTRAINT CKC_IDBAIXITAFS_USR_SAP_ITMAF CHECK (IDBAIXITAFS IS NULL OR (IDBAIXITAFS IN ('1','2','3'))),
         -- null = em aberto, 1 = parcial, 2 = total e 3  = manual
     QTATENDPEDOL                FLOAT                                NULL,
     GENERICO                    VARCHAR2(1)          DEFAULT 'N' NOT NULL,
     EXTRA                       VARCHAR2(4000)                       NULL,
     SERVICO                     VARCHAR2(1)          DEFAULT 'N' NOT NULL,
         CONSTRAINT CKC_SERVICO_USR_ITMAF CHECK (SERVICO IN ('S','N')),
     CANCELADO                   VARCHAR2(01)         DEFAULT 'N' NOT NULL
         CONSTRAINT CKC_CANCELADO_USR_ITMAF CHECK (CANCELADO IN ('S','N')),
         -- N = Pedido no cancelado e S = Pedido cancelado
     IDINTERFACE                 NUMBER                           NOT NULL,
     TPINTERFACE                 VARCHAR2(01)                     NOT NULL
	     CONSTRAINT CKC_TPINTERFACE_USR_ITMAF CHECK (TPINTERFACE IN ('I','A','E')),
	     --Tipo de transao realizada - I = Incluso, A = Alterao e E = Excluso
     DTINTERFACEORI              DATE                             NOT NULL,
     DTINTERFACEDEST             DATE                                 NULL,
     STATUS                      NUMBER                            NOT NULL
  	     CONSTRAINT CKC_STATUS_USR_SAP_ITMAF CHECK (STATUS IN (0,1,2,3)),
	     -- 0 = ok, 1 = novo, 2 = erro e 3 = em processamento
     APPORIGEM                   NUMBER                            NOT NULL
  	     CONSTRAINT CKC_APPORIGEM_USR_SAP_ITMAF CHECK (APPORIGEM IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
     APPDESTINO                  NUMBER                            NOT NULL
	     CONSTRAINT CKC_APPDESTINO_USR_SAP_ITMAF CHECK (APPDESTINO IN (1,2,4)),
		 -- 1 = Teknisa e 2 = SAP/ME
     NRORG                       NUMBER                DEFAULT 1   NOT NULL,
     IDATIVO                     VARCHAR2(1)           DEFAULT 'S' NOT NULL
         CONSTRAINT CKC_IDATIVO_USR_ITEMAUTF CHECK (IDATIVO IN ('S','N')),
     DTINCLUSAO                  DATE                                  NULL,
     DTULTATU                    DATE                                  NULL,
     NRORGINCLUSAO               NUMBER                DEFAULT 1       NULL,
     CDOPERINCLUSAO              VARCHAR2(12)          DEFAULT '1'     NULL,
     NRORGULTATU                 NUMBER                DEFAULT 1       NULL,
     CDOPERULTATU                VARCHAR2(12)          DEFAULT '1'     NULL,
     IDINTERFACEAF               NUMBER                                NULL,
     CDPRODARVORIG               VARCHAR2(10)                          NULL
)
/

CREATE INDEX SUP00328_FK ON USR_SAP_ITEMAUTF(NUMEROITEM, CDPRODUTO, IDENTIFIC)
/

-- ============================================================
--   TABLE: USR_SAP_ENVIOAFFORN
-- ============================================================
CREATE TABLE USR_SAP_ENVIOAFFORN
(
     ALTERACAO                   VARCHAR2(01)          DEFAULT 'T' NOT NULL,
     IDENTIFIC                   VARCHAR2(10)                      NOT NULL,
     NRSEQENVIOAFORN             VARCHAR2(10)                      NOT NULL,
     CDFORNECED                  VARCHAR2(21)                      NOT NULL,
     DSUSUARIOME                 VARCHAR2(200)                         NULL,
     DTDOWNLOAD                  DATE                                  NULL,
     DTRECEBEENVAF               DATE                                  NULL,
     IDTIPENVLIDO                VARCHAR2(01)                          NULL,
     CANCELADO                   VARCHAR2(01)          DEFAULT 'N' NOT NULL
         CONSTRAINT CKC_CANCELADO_USR_ENVAF CHECK (CANCELADO IN ('S','N')),
         -- N = Pedido no cancelado e S = Pedido cancelado
     IDINTERFACE                 NUMBER                            NOT NULL,
     TPINTERFACE                 VARCHAR2(01)                      NOT NULL
	     CONSTRAINT CKC_TPINTERFACE_USR_ENVAF CHECK (TPINTERFACE IN ('I','A','E')),
	     --Tipo de transao realizada - I = Incluso, A = Alterao e E = Excluso
     DTINTERFACEORI              DATE                              NOT NULL,
     DTINTERFACEDEST             DATE                                  NULL,
     STATUS                      NUMBER                            NOT NULL
  	     CONSTRAINT CKC_STATUS_USR_SAP_ENVAF CHECK (STATUS IN (0,1,2,3)),
	     -- 0 = ok, 1 = novo, 2 = erro e 3 = em processamento
     APPORIGEM                   NUMBER                            NOT NULL
  	     CONSTRAINT CKC_APPORIGEM_USR_SAP_ENVAF CHECK (APPORIGEM IN (1,2,4)),
         -- 1 = Teknisa e 2 = SAP/ME
     APPDESTINO                  NUMBER                            NOT NULL
	     CONSTRAINT CKC_APPDESTINO_USR_SAP_ENVAF CHECK (APPDESTINO IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
     NRORG                       NUMBER                DEFAULT 1   NOT NULL,
     IDATIVO                     VARCHAR2(1)           DEFAULT 'S' NOT NULL
         CONSTRAINT CKC_IDATIVO_USR_ENVIOAFFORN CHECK (IDATIVO IN ('S','N')),
     DTINCLUSAO                  DATE                                  NULL,
     DTULTATU                    DATE                                  NULL,
     NRORGINCLUSAO               NUMBER                DEFAULT 1       NULL,
     CDOPERINCLUSAO              VARCHAR2(12)          DEFAULT '1'     NULL,
     NRORGULTATU                 NUMBER                DEFAULT 1       NULL,
     CDOPERULTATU                VARCHAR2(12)          DEFAULT '1'     NULL
)
/

CREATE INDEX SUP00329_FK ON USR_SAP_ENVIOAFFORN(IDENTIFIC, NRSEQENVIOAFORN)
/

-- ============================================================
--   TABLE: USR_SAP_PRAZOPGTAF
-- ============================================================
CREATE TABLE USR_SAP_PRAZOPGTAF
(
     ALTERACAO                   VARCHAR2(01)          DEFAULT 'T' NOT NULL,
     IDENTIFIC                   VARCHAR2(10)                      NOT NULL,
     CENTRO                      VARCHAR2(04)                      NOT NULL,
     NRSEQPGTIOAFORN             VARCHAR2(10)                      NOT NULL,
     NRDIASPGTOAF                NUMBER                            NOT NULL,
     VRPERCPGTOAF                FLOAT                             NOT NULL,
     CANCELADO                   VARCHAR2(01)          DEFAULT 'N' NOT NULL
         CONSTRAINT CKC_CANCELADO_USR_PGTAF CHECK (CANCELADO IN ('S','N')),
         -- N = Pedido no cancelado e S = Pedido cancelado
     IDINTERFACE                 NUMBER                            NOT NULL,
     TPINTERFACE                 VARCHAR2(01)                      NOT NULL
	     CONSTRAINT CKC_TPINTERFACE_USR_PGTAF CHECK (TPINTERFACE IN ('I','A','E')),
	     --Tipo de transao realizada - I = Incluso, A = Alterao e E = Excluso
     DTINTERFACEORI              DATE                              NOT NULL,
     DTINTERFACEDEST             DATE                                  NULL,
     STATUS                      NUMBER                            NOT NULL
  	     CONSTRAINT CKC_STATUS_USR_SAP_PGTAF CHECK (STATUS IN (0,1,2,3)),
	     -- 0 = ok, 1 = novo, 2 = erro e 3 = em processamento
     APPORIGEM                   NUMBER                            NOT NULL
  	     CONSTRAINT CKC_APPORIGEM_USR_SAP_PGTAF CHECK (APPORIGEM IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
     APPDESTINO                  NUMBER                            NOT NULL
	     CONSTRAINT CKC_APPDESTINO_USR_SAP_PGTAF CHECK (APPDESTINO IN (1,2,4)),
	     -- 1 = Teknisa e 2 = SAP/ME
     NRORG                       NUMBER                DEFAULT 1   NOT NULL,
     IDATIVO                     VARCHAR2(1)           DEFAULT 'S' NOT NULL
         CONSTRAINT CKC_IDATIVO_USR_PRAZOPGTAF CHECK (IDATIVO IN ('S','N')),
     DTINCLUSAO                  DATE                                  NULL,
     DTULTATU                    DATE                                  NULL,
     NRORGINCLUSAO               NUMBER                DEFAULT 1       NULL,
     CDOPERINCLUSAO              VARCHAR2(12)          DEFAULT '1'     NULL,
     NRORGULTATU                 NUMBER                DEFAULT 1       NULL,
     CDOPERULTATU                VARCHAR2(12)          DEFAULT '1'     NULL
)
/

CREATE INDEX SUP00330_FK ON USR_SAP_PRAZOPGTAF(IDENTIFIC, NRSEQPGTIOAFORN)
/

-- ============================================================
-- SEQUENCE 
-- ============================================================
CREATE SEQUENCE USR_SAP_ME_EN_IDINTERFACE INCREMENT BY 1 MINVALUE 1
/

CREATE SEQUENCE USR_SAP_AF_IDINTERFACE INCREMENT BY 1 MINVALUE 1
/

CREATE SEQUENCE USR_SAP_ENVAF_IDINTERFACE INCREMENT BY 1 MINVALUE 1
/

CREATE SEQUENCE USR_SAP_PGTAF_IDINTERFACE INCREMENT BY 1 MINVALUE 1
/

CREATE SEQUENCE USR_SAP_ITMAF_IDINTERFACE INCREMENT BY 1 MINVALUE 1
/

-- ============================================================
--   TABLE: FORNECEDOR 
-- ============================================================
ALTER TABLE FORNECEDOR ADD USR_INTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_FORN CHECK (USR_INTEGRAMESAP IN ('S','N'))
/

-- ============================================================
--   TABLE: PAIS 
-- ============================================================
ALTER TABLE PAIS ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_PAIS CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

-- ============================================================
--   TABLE: MUNICIPIO 
-- ============================================================
ALTER TABLE MUNICIPIO ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_MUN CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

-- ============================================================
--   TABLE: BAIRRO 
-- ============================================================
ALTER TABLE BAIRRO ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_BAIRRO CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

-- ============================================================
--   TABLE: ENDEFILI 
-- ============================================================
ALTER TABLE ENDEFILI ADD IDUSR_SAP_ME_ENDERECO VARCHAR2(10) NULL
/

ALTER TABLE ENDEFILI ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_END CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))

/

-- ============================================================
--   TABLE: ENDECLIE 
-- ============================================================
ALTER TABLE ENDECLIE ADD IDUSR_SAP_ME_ENDERECO VARCHAR2(10) NULL
/

ALTER TABLE ENDECLIE ADD IDUSR_SAP_ME_ENDERECO_FAT VARCHAR2(10) NULL
/

ALTER TABLE ENDECLIE ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_ENDCLIE CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

-- ============================================================
--   TABLE: EMPRESA 
-- ============================================================
ALTER TABLE EMPRESA ADD IDUSR_SAP_ME_ENDERECO VARCHAR2(10) NULL
/                                                           

ALTER TABLE EMPRESA ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_EMPRESA CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

ALTER TABLE EMPRESA ADD IDUSR_SAP_ME_ENDERECO_FAT VARCHAR2(10) NULL
/

-- ============================================================
--   TABLE: EMPRCNTRFIL 
-- ============================================================
ALTER TABLE EMPRCNTRFIL ADD IDUSR_SAP_ME_ENDERECO VARCHAR2(10) NULL
/

ALTER TABLE EMPRCNTRFIL ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_EMPFIL CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

ALTER TABLE EMPRCNTRFIL ADD IDUSR_SAP_ME_ENDERECO_FAT VARCHAR2(10) NULL
/

-- ============================================================
--   TABLE: CLIENFILIAL 
-- ============================================================
ALTER TABLE CLIENFILIAL ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_CLIEFIL CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

-- ============================================================
--   TABLE: AUTOFORNE 
-- ============================================================
ALTER TABLE AUTOFORNE ADD USR_TPINTERFACE_SAP VARCHAR2(01) NULL
/

ALTER TABLE AUTOFORNE ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_AF CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

-- ============================================================
--   TABLE: ITEMAUTF 
-- ============================================================
ALTER TABLE ITEMAUTF ADD USR_TPINTERFACE_SAP VARCHAR2(01) NULL
/                              

ALTER TABLE ITEMAUTF ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_ITMAF CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/                                                                                              

-- ============================================================
--   TABLE: INSCRESTAD
-- ============================================================
ALTER TABLE INSCRESTAD ADD USR_IDINTEGRAMESAP VARCHAR2(1)
 CONSTRAINT CKC_USR_INTEGRAMESAP_INSCEST CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/                                                                                              

-- ============================================================
--   TABLE: PRAZOPGTAF
-- ============================================================
ALTER TABLE PRAZOPGTAF ADD USR_TPINTERFACE_SAP VARCHAR2(01) NULL
/                                                                                              

ALTER TABLE PRAZOPGTAF ADD USR_IDINTEGRAMESAP VARCHAR2(01) NULL
 CONSTRAINT CKC_USR_INTEGRAMESAP_PGTAF CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

-- ============================================================
--   TABLE: ENVIOAFFORN
-- ============================================================
ALTER TABLE ENVIOAFFORN ADD USR_TPINTERFACE_SAP VARCHAR2(01) NULL
/

ALTER TABLE ENVIOAFFORN ADD USR_IDINTEGRAMESAP VARCHAR2(01) NULL
 CONSTRAINT CKC_USR_INTEGRAMESAP_ENVAF CHECK ((USR_IDINTEGRAMESAP IS NULL)OR(USR_IDINTEGRAMESAP IN ('S','N')))
/

ALTER TABLE USR_SAP_ENVIOAFFORN ADD DSTCLASSENVAFOR VARCHAR2(40)
/

ALTER TABLE USR_SAP_ME_ENDERECO ADD DSLOCAL VARCHAR2(300)
/

ALTER TABLE USR_SAP_ITEMAUTF ADD CDFABRICANTE VARCHAR2(5)
/

-- VERSAO --
BEGIN ATUVEROBJ('ATUALIZACAO_ESTRUTURA_BD','6.10.046'); END;
/
